﻿using System;
using System.IO;
using System.Linq;
using Rhino.FileIO;

namespace test_rhino3dm_console
{
  class Program
  {
    static void Main(string[] args)
    {
      if (0 == args.Length)
      {
        Console.WriteLine("Rhino file not specified.");
        return;
      }

      var filename = args[0].Trim();
      if (string.IsNullOrEmpty(filename))
      {
        Console.WriteLine("Rhino file not specified.");
        return;
      }

      var extension = Path.GetExtension(filename);
      if (string.IsNullOrEmpty(extension))
      {
        Console.WriteLine("Specified file is not a Rhino file.");
        return;
      }

      var rhino_extensions = new string[] { ".3dm", ".3dmbak" };
      if (!rhino_extensions.Contains(extension))
      {
        Console.WriteLine("Specified file is not a Rhino file.");
        return;
      }

      if (!File.Exists(filename))
      {
        Console.WriteLine("Specified file not found.");
        return;
      }

      using (var f = File3dm.Read(filename))
      {
        Console.WriteLine($"{f.Strings.Count + 1} document user strings.");
        for (var i = 0; i < f.Strings.Count; i++)
        {
          var key = f.Strings.GetKey(i);
          var value = f.Strings.GetValue(key);
          Console.WriteLine($"{i}: Key = {key}, Value = {value}.");
        }
      }
    }
  }
}
